``Pylint`` warns about options it doesn't recognize both in configuration files
and on the command-line. For example, this message would be raised when invoking
pylint with ``pylint --unknown-option=yes test.py``.
